# Kodexa

![Build/Deploy](https://github.com/kodexa-ai/kodexa/workflows/Build%20Python%20Package%20(Development)/badge.svg?branch=master) ![https://docs.readthedocs.io/en/latest/?badge=latest](https://readthedocs.org/projects/docs/badge/?version=latest) 

The Kodexa Content Framework framework is designed to allow you to work with a wide range of unstructured and semi-structured content and enables you to work with the Kodexa Cloud (https://kodexa.com).

## Documentation & Examples

Documentation is available at [ReadTheDocs](https://kodexa-kodexa.readthedocs-hosted.com/en/latest/)

For more information on how to use Mango see https://developer.kodexa.com/

## Set-up

Ensure you have Anaconda 3 or greater installed, then run:

    conda env create -f environment.yml --force
    
Activate the conda environment with the command:

    conda activate kodexa
    

    
